@@ -60,9 +60,6 @@ globus_i_gsi_proxy_openssl_error_result(
     globus_object_t *                   error_object;
     globus_result_t                     result;
 
-    static char *                       _function_name_ =
-        "globus_i_gsi_proxy_openssl_error_result";
-
     GLOBUS_I_GSI_PROXY_DEBUG_ENTER;
 
     error_object =
@@ -100,9 +97,6 @@ globus_i_gsi_proxy_error_result(
     globus_object_t *                   error_object;
     globus_result_t                     result;
 
-    static char *                       _function_name_ =
-        "globus_i_gsi_proxy_error_result";
-
     GLOBUS_I_GSI_PROXY_DEBUG_ENTER;
 
     error_object = globus_error_construct_error(
@@ -140,9 +134,6 @@ globus_i_gsi_proxy_error_chain_result(
 {
     globus_result_t                     result;
     globus_object_t *                   error_object;
-    
-    static char *                       _function_name_ =
-        "globus_i_gsi_proxy_error_chain_result";
 
     GLOBUS_I_GSI_PROXY_DEBUG_ENTER;
 
